@@ -807,7 +807,8 @@ POOL_STATUS Execute(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend,
 		/*
 		 * Take care of "writing transaction" flag.
 		 */
-		if (!is_select_query(node, query) && !is_start_transaction_query(node))
+		if (!is_select_query(node, query) && !is_start_transaction_query(node) &&
+			!is_commit_or_rollback_query(node))
 		{
 			ereport(DEBUG1,
 					(errmsg("Execute: TSTATE:%c",
@@ -3178,6 +3179,8 @@ static POOL_STATUS parse_before_bind(POOL_CONNECTION *frontend,
 	
 	if (!STREAM && parse_was_sent)
 	{
+		pool_set_query_in_progress();
+
 		while (kind != '1')
 		{
 			PG_TRY();
@@ -3558,7 +3561,7 @@ void pool_at_command_success(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *ba
 	if (!pool_is_command_success())
 	{
 		ereport(ERROR,
-				(errmsg("pool_at_command_success: command did not suceed")));
+				(errmsg("pool_at_command_success: command did not succeed")));
 	}
 
 	node = pool_get_parse_tree();
