@@ -1,9 +1,11 @@
 /* -*-pgsql-c-*- */
 /*
+ * $Header$
+ *
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2019	PgPool Global Development Group
+ * Copyright (c) 2003-2014	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -41,7 +43,6 @@ static bool	insertinto_or_locking_clause_walker(Node *node, void *context);
 static bool is_immutable_function(char *fname);
 static bool select_table_walker(Node *node, void *context);
 static bool non_immutable_function_call_walker(Node *node, void *context);
-static char *make_table_name_from_rangevar(RangeVar *rangevar);
 static char *strip_quote(char *str);
 
 /*
@@ -191,14 +192,7 @@ int pattern_compare(char *str, const int type, const char *param_name)
 	}
 
 	s = strip_quote(str);
-	if (!s)
-	{
-		elog(WARNING, "pattern_compare: strip_quote() returns error");
-		return -1;
-	}
-
-	for (i = 0; i < *pattc; i++)
-	{
+	for (i = 0; i < *pattc; i++) {
 		if (lists_patterns[i].type != type)
 			continue;
 
@@ -240,31 +234,12 @@ int pattern_compare(char *str, const int type, const char *param_name)
 	return result;
 }
 
-/*
- * Returns double quotes stripped version of malloced string.
- * Callers must free() after using it.
- * Returns NULL on error.
- */
-static char *
-strip_quote(char *str)
+static char *strip_quote(char *str)
 {
-	char	   *after;
-	int		   len;
-	int			i = 0;
+	char *after;
+	int i = 0;
 
-	len = strlen(str);
-	after = malloc(sizeof(char) * len + 1);
-	if (!after)
-	{
-		return NULL;
-	}
-
-	if (len == 0)
-	{
-		/* empty string case */
-		*after = '\0';
-		return after;
-	}
+	after = malloc(sizeof(char) * strlen(str) + 1);
 
 	do {
 		if (*str != '"')
@@ -476,7 +451,7 @@ static bool is_system_catalog(char *table_name)
 
 #define ISBELONGTOPGCATALOGQUERY2 "SELECT count(*) FROM pg_class AS c, pg_namespace AS n WHERE c.oid = pgpool_regclass('\"%s\"') AND c.relnamespace = n.oid AND n.nspname = 'pg_catalog'"
 
-#define ISBELONGTOPGCATALOGQUERY3 "SELECT count(*) FROM pg_class AS c, pg_namespace AS n WHERE c.oid = pg_catalog.to_regclass('\"%s\"') AND c.relnamespace = n.oid AND n.nspname = 'pg_catalog'"
+#define ISBELONGTOPGCATALOGQUERY3 "SELECT count(*) FROM pg_class AS c, pg_namespace AS n WHERE c.oid = to_regclass('\"%s\"') AND c.relnamespace = n.oid AND n.nspname = 'pg_catalog'"
 
 	int hasreliscatalog;
 	bool result;
@@ -583,7 +558,7 @@ static bool is_temp_table(char *table_name)
  * regclass (or its variant) here, because temporary tables never have
  * schema qualified name.
  */
-#define ISTEMPQUERY83 "SELECT count(*) FROM pg_catalog.pg_class AS c, pg_namespace AS n WHERE c.relname = '%s' AND c.relnamespace = n.oid AND n.nspname ~ '^pg_temp_'"
+#define ISTEMPQUERY83 "SELECT count(*) FROM pg_class AS c, pg_namespace AS n WHERE c.relname = '%s' AND c.relnamespace = n.oid AND n.nspname ~ '^pg_temp_'"
 
 /*
  * Query to know if the target table is a temporary one.  This query
@@ -683,7 +658,7 @@ bool is_unlogged_table(char *table_name)
 
 #define ISUNLOGGEDQUERY2 "SELECT count(*) FROM pg_catalog.pg_class AS c WHERE c.oid = pgpool_regclass('%s') AND c.relpersistence = 'u'"
 
-#define ISUNLOGGEDQUERY3 "SELECT count(*) FROM pg_catalog.pg_class AS c WHERE c.oid = pg_catalog.to_regclass('%s') AND c.relpersistence = 'u'"
+#define ISUNLOGGEDQUERY3 "SELECT count(*) FROM pg_catalog.pg_class AS c WHERE c.oid = to_regclass('%s') AND c.relpersistence = 'u'"
 
 	int hasrelpersistence;
 	static POOL_RELCACHE *hasrelpersistence_cache;
@@ -777,7 +752,7 @@ bool is_view(char *table_name)
 
 #define ISVIEWQUERY2 "SELECT count(*) FROM pg_catalog.pg_class AS c WHERE c.oid = pgpool_regclass('%s') AND (c.relkind = 'v' OR c.relkind = 'm')"
 
-#define ISVIEWQUERY3 "SELECT count(*) FROM pg_catalog.pg_class AS c WHERE c.oid = pg_catalog.to_regclass('%s') AND (c.relkind = 'v' OR c.relkind = 'm')"
+#define ISVIEWQUERY3 "SELECT count(*) FROM pg_catalog.pg_class AS c WHERE c.oid = to_regclass('%s') AND (c.relkind = 'v' OR c.relkind = 'm')"
 
 	static POOL_RELCACHE *relcache;
 	POOL_CONNECTION_POOL *backend;
@@ -873,7 +848,7 @@ bool pool_has_to_regclass(void)
 /*
  * Query to know if to_regclass exists.
  */
-#define HAS_TOREGCLASSQUERY "SELECT count(*) from (SELECT has_function_privilege('%s', 'pg_catalog.to_regclass(cstring)', 'execute') WHERE EXISTS(SELECT * FROM pg_catalog.pg_proc AS p WHERE p.proname = 'to_regclass')) AS s"
+#define HAS_TOREGCLASSQUERY "SELECT count(*) from (SELECT has_function_privilege('%s', 'to_regclass(cstring)', 'execute') WHERE EXISTS(SELECT * FROM pg_catalog.pg_proc AS p WHERE p.proname = 'to_regclass')) AS s"
 
 	bool result;
 	static POOL_RELCACHE *relcache;
@@ -1046,7 +1021,7 @@ int pool_table_name_to_oid(char *table_name)
  */
 #define TABLE_TO_OID_QUERY "SELECT pgpool_regclass('%s')"
 #define TABLE_TO_OID_QUERY2 "SELECT oid FROM pg_class WHERE relname = '%s'"
-#define TABLE_TO_OID_QUERY3 "SELECT COALESCE(pg_catalog.to_regclass('%s')::oid, 0)"
+#define TABLE_TO_OID_QUERY3 "SELECT COALESCE(to_regclass('%s')::oid, 0)"
 
 	int oid = 0;
 	static POOL_RELCACHE *relcache;
@@ -1210,7 +1185,7 @@ makeRangeVarFromNameList(List *names)
  * necessary.  The returned table name is in static area. So next
  * call to this function will break previous result.
  */
-static char *make_table_name_from_rangevar(RangeVar *rangevar)
+char *make_table_name_from_rangevar(RangeVar *rangevar)
 {
 	/*
 	 * Table name. Max size is calculated as follows:
